using FlexCel.Core;
using FlexCel.Pdf;
using FlexCel.Render;
using FlexCel.Report;
using FlexCel.XlsAdapter;
using System.Reflection;

namespace AndroidFlexcelTestApp
{
   [Activity(Label = "@string/app_name", MainLauncher = true)]
   public class MainActivity : Activity
   {
      protected override void OnCreate(Bundle? savedInstanceState)
      {
         base.OnCreate(savedInstanceState);

         // Set our view from the "main" layout resource
         SetContentView(Resource.Layout.activity_main);

         Button coldstartbutton = FindViewById<Button>(Resource.Id.coldstartbutton);
         coldstartbutton.Click += ColdStartButtonOnClick;
      }

      private void ColdStartButtonOnClick(object sender, EventArgs eventArgs)
      {
         ColdStart();
      }


      private void ColdStart()
      {
         Assembly assembly = Assembly.GetExecutingAssembly();
         bool startedSuccessfully = true;
         using (Stream coldStartTemplateStream = assembly.GetManifestResourceStream("AndroidFlexcelTestApp.Resources.result.xlsx"))
         {
            using (MemoryStream flexCelReportResultStream = new MemoryStream())
            {
               XlsFile xls = null;
               try
               {
                  using (FlexCelReport fr = new FlexCelReport(true))
                  {
                     fr.DisableSQLValidation = true;
                     fr.Run(coldStartTemplateStream, flexCelReportResultStream);
                     flexCelReportResultStream.Position = 0;

                     xls = new XlsFile(true);
                     string pathToSave = Path.Combine(GetExternalFilesDir(null).AbsolutePath, "result.xlsx");
                     xls.Open(flexCelReportResultStream);
                     xls.Save(pathToSave);
                  }
               }
               catch (Exception e)
               {
                  startedSuccessfully = false;
               }

               if (xls != null && startedSuccessfully)
               {
                  startedSuccessfully = MakeInMemoryPdf(xls);
               }
            }
         }

         if (startedSuccessfully)
         {
         }
      }

      private bool MakeInMemoryPdf(XlsFile xls)
      {
         FlexCelConfig.GraphicFramework = FlexCelGraphicFramework.Native;
         FlexCelTrace.OnError += HandleOnFlexcelError;
         bool result = true;
         using (MemoryStream pdfStream = new MemoryStream())
         {
            using (FlexCelPdfExport pdf = new FlexCelPdfExport(xls, true))
            {
               try
               {

                  string pathToSave = Path.Combine(GetExternalFilesDir(null).AbsolutePath, "result.pdf");
                  pdf.FontMapping = TFontMapping.ReplaceAllFonts;
                  pdf.GetFontData += HandleOnGetFontData;
                  pdf.BeforeGeneratePage += HandleOnBeforeGeneratingPage;
                  pdf.OnFontFolderNotFound = TPdfFontFolderNotFoundAction.Ignore;
                  pdf.UnlicensedFontAction = TUnlicensedFontAction.Ignore;
                  pdf.AfterGeneratePage += HandleOnAfterGeneratingPage;
                  pdf.GetFontFolder += HandleOnGetFontFolder;
                 
                  pdf.ExportAllVisibleSheets(pathToSave,true,null);
                  result = true;
               }

               catch (Exception e)
               {
                  result = false;
               }
            }
         }

         return result;
      }

      private void HandleOnAfterGeneratingPage(object sender, PageEventArgs e)
      {
         
      }

      private void HandleOnGetFontFolder(object sender, GetFontFolderEventArgs e)
      {
      }

      private void HandleOnBeforeGeneratingPage(object sender, PageEventArgs e)
      {
      }

      private void HandleOnGetFontData(object sender, GetFontDataEventArgs e)
      {
      }

      private void HandleOnFlexcelError(TFlexCelErrorInfo e)
      {
      }
   }
}